@@ -62,6 +62,11 @@ def save_equity_daily_data(data_df = None, ticker=None, provider = 'napoleon', s
         '%d_%b_%Y') + '_daily_returns.pkl'
     data_df.to_pickle(local_root_directory + filename)
 
+def save_crypto_daily_data(data_df = None, ticker ='crypto_lo', return_pkl_suffix = '_daily_returns.pkl', starting_date=None,running_date=None,local_root_directory=None):
+    filename = ticker + '_' + starting_date.strftime('%d_%b_%Y') + '_' + running_date.strftime(
+        '%d_%b_%Y') + return_pkl_suffix
+    print(f'saving {local_root_directory + filename}')
+    data_df.to_pickle(local_root_directory + filename)
 
 def fetch_equity_daily_data(data = None, ticker=None, provider = 'yahoo', starting_date=None,running_date=None,local_root_directory=None):
     yahoo_tickers_equivalents = {
