@@ -2,7 +2,7 @@
 # coding: utf-8
 
 
-def  generate_augmento_simple(transform_featuress, los, magnitudes, nb_selecteds, leading_correlationss):
+def generate_augmento_simple(transform_featuress, los, magnitudes, nb_selecteds, leading_correlationss):
     parameters = []
     for transform_features in transform_featuress:
         for lo in los:
@@ -18,24 +18,24 @@ def  generate_augmento_simple(transform_featuress, los, magnitudes, nb_selecteds
                         })
     return parameters
 
-def generate_simple_baseline(thresholds, signal_types, mixing_types):
+def generate_simple_baseline(thresholds, signal_action_types, mixing_types):
     parameters = []
     for threshold in thresholds:
-        for signal_type in signal_types:
+        for signal_action_type in signal_action_types:
             for mixing_type in mixing_types:
                 parameters.append({
                     'threshold': threshold,
-                    'signal_type': signal_type,
+                    'signal_action_type': signal_action_type,
                     'mixing_type': mixing_type,
                 })
     return parameters
 
-def generate_anova_like(signal_types, mixing_types):
+def generate_anova_like(signal_action_types, mixing_types):
     parameters = []
-    for signal_type in signal_types:
+    for signal_action_type in signal_action_types:
         for mixing_type in mixing_types:
             parameters.append({
-                'signal_type': signal_type,
+                'signal_action_type': signal_action_type,
                 'mixing_type': mixing_type,
             })
     return parameters
